Installation
--------------

``dms_variants`` requires Python 3.6 or higher.

The easiest way to install ``dms_variants`` is from `PyPI <https://pypi.org/>`_ using `pip <https://pip.pypa.io>`_ with::

    pip install dms_variants

The source code for ``dms_variants`` is available on GitHub at https://github.com/jbloomlab/dms_variants.
